from django.db import models
from django.utils.translation import gettext_lazy as _
from assignments import models as assignments_models

class Location(models.Model):

    class Modality(models.TextChoices):
        onsite = 'onsite', _('Onsite')
        online = 'online', _('Online')
        hybrid = 'hybrid', _('Hybrid')

    mode = models.CharField(
        max_length=6,
        choices=Modality.choices,
        default=Modality.onsite
    )
    venue = models.TextField(default='')

    def __str__(self):
        return '{} ({})'.format(self.venue, self.mode)

class Event(models.Model):
    target_datetime = models.DateTimeField(default='')
    activity = models.TextField(default='')
    estimated_hours = models.FloatField(default='')
    location = models.ForeignKey(Location, on_delete=models.CASCADE)
    course = models.ForeignKey(assignments_models.Course, on_delete=models.CASCADE)
    
    def __str__(self):
        return '{} on {} at {}'.format(
            self.activity,
            self.target_datetime.strftime("%m/%d/%y"),
            self.target_datetime.strftime("%I:%M %p"),
            )